@@ -8,20 +8,55 @@ from datetime import datetime
 
 # Third Party
 import pytz
-from aadiscordbot.app_settings import get_site_url
 from discord.colour import Color
 from discord.embeds import Embed
 from discord.ext import commands
 
 # Django
 from django.conf import settings
-from django.urls import reverse
+
+# Alliance Auth (External Libs)
+from app_utils.urls import reverse_absolute
 
 # AA Time Zones
 from timezones.constants import AA_TIMEZONE_DEFAULT_PANELS
 from timezones.models import Timezones
 
 
+def add_empty_field(embed: Embed) -> None:
+    """
+    Adding an empty field to the embed.
+
+    :param embed:
+    :type embed:
+    :return:
+    :rtype:
+    """
+
+    embed.add_field(
+        name="\u200b",
+        value="\u200b",
+        inline=True,
+    )
+
+
+def add_empty_line(embed: Embed) -> None:
+    """
+    Adding an empty line to the embed.
+
+    :param embed:
+    :type embed:
+    :return:
+    :rtype:
+    """
+
+    embed.add_field(
+        name="\u200b",
+        value="\u200b",
+        inline=False,
+    )
+
+
 class Time(commands.Cog):
     """
     A series of Time tools
@@ -31,39 +66,36 @@ class Time(commands.Cog):
         self.bot = bot
 
     @classmethod
-    def show_timezones(cls, deprecated_command_used: bool = False):
+    def show_timezones(cls) -> Embed:
         """
-        Create and format the embed for Discord
-        :param deprecated_command_used:
+        Create and format the embed for Discord.
+
         :return:
+        :rtype:
         """
 
         fmt_utc = "%H:%M:%S (UTC)\n%A %d. %b %Y"
         fmt = "%H:%M:%S (UTC %z)\n%A %d. %b %Y"
         utc_now = datetime.utcnow()
-        # utc_timestamp = utc_now.strftime("%s")
+        utc_timestamp = utc_now.strftime("%s")
 
         embed = Embed(title="Time")
         embed.colour = Color.green()
 
-        # embed.add_field(
-        #     name="Your Local Time",
-        #     # value=f"<t:{utc_timestamp}:T>\n<t:{utc_timestamp}:D>",
-        #     value=f"<t:{utc_timestamp}:T>",
-        #     inline=True,
-        # )
+        embed.add_field(
+            name="Your Local Time",
+            value=f"<t:{utc_timestamp}:T>\n<t:{utc_timestamp}:D>",
+            inline=True,
+        )
 
         embed.add_field(
-            name="EVE Time",
+            name="Eve Time",
             value=utc_now.strftime(fmt_utc),
             inline=True,
         )
 
-        # embed.add_field(
-        #     name="\u200b",
-        #     value="\u200b",
-        #     inline=True,
-        # )
+        add_empty_field(embed=embed)
+        add_empty_line(embed=embed)
 
         configured_timezones = (
             Timezones.objects.select_related("timezone")
@@ -103,8 +135,10 @@ class Time(commands.Cog):
                     inline=True,
                 )
 
+        add_empty_line(embed=embed)
+
         # Add url to the timezones module
-        timezones_url = get_site_url() + reverse("timezones:index")
+        timezones_url = reverse_absolute("timezones:index")
 
         embed.add_field(
             name="Timezones Conversion",
@@ -112,33 +146,20 @@ class Time(commands.Cog):
             inline=False,
         )
 
-        if deprecated_command_used:
-            embed.add_field(
-                name="Deprecation Warning",
-                value=(
-                    "You used the deprecated `!time` command, which will be removed in "
-                    "the foreseeable future. Please use `/time` instead."
-                ),
-                inline=False,
-            )
-
         return embed
 
-    @commands.command(pass_context=True)
+    @commands.slash_command(name="time", guild_ids=[int(settings.DISCORD_GUILD_ID)])
     async def time(self, ctx):
         """
-        Returns the Eve time and the current time in various time zones
+        Returns the Eve time, and the current time in various time zones.
+
+        :param ctx:
+        :type ctx:
+        :return:
+        :rtype:
         """
 
-        return await ctx.send(embed=self.show_timezones(deprecated_command_used=True))
-
-    @commands.slash_command(name="time", guild_ids=[int(settings.DISCORD_GUILD_ID)])
-    async def time_slash(self, ctx):
-        """
-        Returns the Eve time and the current time in various time zones
-        """
-
-        return await ctx.respond(embed=self.show_timezones())
+        return await ctx.respond(embed=self.show_timezones(), ephemeral=True)
 
 
 def setup(bot):
@@ -147,7 +168,7 @@ def setup(bot):
     :param bot:
     """
 
-    # Unload the `time` extension from `aadiscordbot`, so we can load our own
+    # Unload the `time` extension from `aadiscordbot`, so we can load our own.
     if bot.get_cog("Time") is not None:
         bot.remove_cog("Time")
 
