@@ -2,9 +2,6 @@
 Hooks to AA
 """
 
-# Django
-from django.utils.translation import gettext_lazy as _
-
 # Alliance Auth
 from allianceauth import hooks
 from allianceauth.services.hooks import MenuItemHook, UrlHook
@@ -23,10 +20,10 @@ class AaTimezonesMenuItem(MenuItemHook):  # pylint: disable=too-few-public-metho
         # Set up menu entry for sidebar
         MenuItemHook.__init__(
             self,
-            _(__title__),
-            "far fa-clock fa-fw",
+            __title__,
+            "fa-regular fa-clock fa-fw",
             "timezones:index",
-            navactive=["timezones:index"],
+            navactive=["timezones:"],
         )
 
     def render(self, request):
@@ -36,10 +33,7 @@ class AaTimezonesMenuItem(MenuItemHook):  # pylint: disable=too-few-public-metho
         :return:
         """
 
-        if request.user.has_perm("timezones.basic_access"):
-            return MenuItemHook.render(self, request)
-
-        return ""
+        return MenuItemHook.render(self, request)
 
 
 @hooks.register("menu_item_hook")
@@ -59,7 +53,12 @@ def register_urls():
     :return:
     """
 
-    return UrlHook(urls, "timezones", r"^timezones/")
+    return UrlHook(
+        urls=urls,
+        namespace="timezones",
+        base_url=r"^timezones/",
+        excluded_views=["timezones.views.index"],
+    )
 
 
 # Only register the cog when aadiscordbot is installed
