@@ -1,11 +1,14 @@
 """
-constants
+Constants
 """
 
 # Standard Library
-from typing import Dict, List, Union
+import os
 
-AA_TIMEZONE_DEFAULT_PANELS: List[Dict[str, Union[str, Dict[str, str]]]] = [
+AA_TIMEZONES_BASE_DIR = os.path.join(os.path.dirname(__file__))
+AA_TIMEZONES_STATIC_DIR = os.path.join(AA_TIMEZONES_BASE_DIR, "static", "timezones")
+
+AA_TIMEZONE_DEFAULT_PANELS: list[dict[str, str | dict[str, str]]] = [
     {
         "panel_name": "US / Pacific",
         "timezone": {
@@ -73,7 +76,7 @@ AA_TIMEZONE_DEFAULT_PANELS: List[Dict[str, Union[str, Dict[str, str]]]] = [
         "panel_name": "Australia / Sydney",
         "timezone": {
             "timezone_name": "Australia/ACT",
-            "panel_id": "australia-atc",
+            "panel_id": "australia-act",
         },
     },
 ]
