@@ -5,13 +5,13 @@ let clockTickId = 0;
 let countdownIntervalId = 0;
 
 /**
- * Show the time adjust section
+ * Show the "time adjust" section
  */
-const showAdjust = () => {
+const showAdjust = () => { // eslint-disable-line no-unused-vars
     'use strict';
 
-    jQuery('#btnadjust').addClass('hidden');
-    jQuery('#adjust').removeClass('hidden');
+    jQuery('#btnadjust').addClass('d-none');
+    jQuery('#adjust').removeClass('d-none');
 
     const mom = moment.tz(new Date(), 'Etc/UTC');
 
@@ -25,11 +25,15 @@ const showAdjust = () => {
 /**
  * Set time for in x day, y hours, z minutes
  */
-const reloadToTimestamp = () => {
+const reloadToTimestamp = () => { // eslint-disable-line no-unused-vars
     'use strict';
 
     const timestamp = (
-        new Date().getTime() / 1000 + jQuery('#tind').val() * 24 * 60 * 60 + jQuery('#tinh').val() * 60 * 60 + jQuery('#tinm').val() * 60
+        new Date()
+            .getTime() / 1000 + jQuery('#tind')
+            .val() * 24 * 60 * 60 + jQuery('#tinh')
+            .val() * 60 * 60 + jQuery('#tinm')
+            .val() * 60
     );
 
     window.location.replace(aaTimezonesOptions.base_url + timestamp);
@@ -38,7 +42,7 @@ const reloadToTimestamp = () => {
 /**
  * Reload to base page
  */
-const reloadBasePage = () => {
+const reloadBasePage = () => { // eslint-disable-line no-unused-vars
     'use strict';
 
     window.location.replace(aaTimezonesOptions.base_url);
@@ -50,7 +54,7 @@ const reloadBasePage = () => {
  * @param {string} str
  * @param {string} tz
  */
-const setdate = (str, tz) => {
+const setdate = (str, tz) => { // eslint-disable-line no-unused-vars
     'use strict';
 
     if (tz !== '') {
@@ -146,20 +150,22 @@ const updatePanels = (now) => {
 
 /**
  * Time until given timestamp
+ *
  * @param {number} timestamp
  */
 const timeUntil = (timestamp) => {
     'use strict';
 
-    const timestampDifference = timestamp - Date.now();
-    let timeDifferenceInSeconds = timestampDifference / 1000; // from ms to seconds
+    /**
+     * Update the countdown
+     */
+    const updateCountdown = () => {
+        const now = Date.now();
+        const timestampDifference = timestamp - now;
+        let timeDifferenceInSeconds = timestampDifference / 1000; // from ms to seconds
 
-    // set the interval
-    countdownIntervalId = setInterval(() => { // execute code each second
         let countdown;
 
-        timeDifferenceInSeconds--; // decrement timestamp with one second each second
-
         if (timeDifferenceInSeconds >= 0) {
             const days = Math.floor(timeDifferenceInSeconds / (24 * 60 * 60)); // calculate days from timestamp
             let hours = Math.floor(timeDifferenceInSeconds / (60 * 60)) % 24; // hours
@@ -170,9 +176,11 @@ const timeUntil = (timestamp) => {
             if (hours < 10) {
                 hours = '0' + hours;
             }
+
             if (minutes < 10) {
                 minutes = '0' + minutes;
             }
+
             if (seconds < 10) {
                 seconds = '0' + seconds;
             }
@@ -183,7 +191,17 @@ const timeUntil = (timestamp) => {
         }
 
         $('.aa-timezones-time-until-countdown').html(countdown);
-    }, 1000);
+
+        // Calculate drift and set the next interval
+        const drift = 1000 - (Date.now() - now);
+
+        countdownIntervalId = setTimeout(
+            updateCountdown,
+            Math.max(0, drift)
+        );
+    };
+
+    updateCountdown();
 };
 
 /**
@@ -216,31 +234,31 @@ const switchto = (mode) => {
     $('.aa-timezones-time-until-countdown').html('');
 
     if (mode === 0) {
-        jQuery('#headlineCurrent').removeClass('hidden');
-        jQuery('#headlineFixed').addClass('hidden');
-        jQuery('#adjust').addClass('hidden');
-        jQuery('#btnadjust').removeClass('hidden');
-        jQuery('#btnshowcurrent').addClass('hidden');
-        jQuery('.aa-timezones-time-until').addClass('hidden');
+        jQuery('#headlineCurrent').removeClass('d-none');
+        jQuery('#headlineFixed').addClass('d-none');
+        jQuery('#adjust').addClass('d-none');
+        jQuery('#btnadjust').removeClass('d-none');
+        jQuery('#btnshowcurrent').addClass('d-none');
+        jQuery('.aa-timezones-time-until').addClass('d-none');
 
         if (clockTarget !== 0) {
-            jQuery('#btnshowfixed').removeClass('hidden');
+            jQuery('#btnshowfixed').removeClass('d-none');
         }
 
-        jQuery('#btnclear').addClass('hidden');
+        jQuery('#btnclear').addClass('d-none');
 
         clockTickId = setInterval(clockTick, 1000);
 
         clockTick();
     } else {
-        jQuery('#headlineCurrent').addClass('hidden');
-        jQuery('#headlineFixed').removeClass('hidden');
-        jQuery('#adjust').addClass('hidden');
-        jQuery('#btnadjust').addClass('hidden');
-        jQuery('#btnshowcurrent').removeClass('hidden');
-        jQuery('#btnshowfixed').addClass('hidden');
-        jQuery('#btnclear').removeClass('hidden');
-        jQuery('.aa-timezones-time-until').removeClass('hidden');
+        jQuery('#headlineCurrent').addClass('d-none');
+        jQuery('#headlineFixed').removeClass('d-none');
+        jQuery('#adjust').addClass('d-none');
+        jQuery('#btnadjust').addClass('d-none');
+        jQuery('#btnshowcurrent').removeClass('d-none');
+        jQuery('#btnshowfixed').addClass('d-none');
+        jQuery('#btnclear').removeClass('d-none');
+        jQuery('.aa-timezones-time-until').removeClass('d-none');
 
         updatePanels(new Date(clockTarget));
         timeUntil(clockTarget);
