@@ -4,7 +4,6 @@ Test utilities
 
 # Standard Library
 import re
-from typing import List
 
 # Django
 from django.contrib.auth.models import User
@@ -21,13 +20,32 @@ def create_fake_user(
     corporation_ticker: str = None,
     alliance_id: int = None,
     alliance_name: str = None,
-    permissions: List[str] = None,
+    permissions: list[str] = None,
 ) -> User:
     """
-    Create a fake user incl. main character and (optional) permissions.
+    Create a fake user
+
+    :param character_id:
+    :type character_id:
+    :param character_name:
+    :type character_name:
+    :param corporation_id:
+    :type corporation_id:
+    :param corporation_name:
+    :type corporation_name:
+    :param corporation_ticker:
+    :type corporation_ticker:
+    :param alliance_id:
+    :type alliance_id:
+    :param alliance_name:
+    :type alliance_name:
+    :param permissions:
+    :type permissions:
+    :return:
+    :rtype:
     """
 
-    username = re.sub(r"[^\w\d@\.\+-]", "_", character_name)
+    username = re.sub(pattern=r"[^\w\d@\.\+-]", repl="_", string=character_name)
     user = AuthUtils.create_user(username)
 
     if not corporation_id:
@@ -51,7 +69,9 @@ def create_fake_user(
     )
 
     if permissions:
-        perm_objs = [AuthUtils.get_permission_by_name(perm) for perm in permissions]
+        perm_objs = [
+            AuthUtils.get_permission_by_name(perm=perm) for perm in permissions
+        ]
         user = AuthUtils.add_permissions_to_user(perms=perm_objs, user=user)
 
     return user
