@@ -3,7 +3,6 @@ The views
 """
 
 # Django
-from django.contrib.auth.decorators import login_required, permission_required
 from django.shortcuts import render
 
 # AA Time Zones
@@ -12,11 +11,10 @@ from timezones.constants import AA_TIMEZONE_DEFAULT_PANELS
 from timezones.models import Timezones
 
 
-@login_required
-@permission_required("timezones.basic_access")
 def index(request, timestamp: str = None):
     """
     Index view
+
     :param request:
     :param timestamp:
     :return:
@@ -33,4 +31,6 @@ def index(request, timestamp: str = None):
 
     context = {"title": __title__, "timezones": timezones, "timestamp": timestamp}
 
-    return render(request, "timezones/index.html", context)
+    return render(
+        request=request, template_name="timezones/index.html", context=context
+    )
